@@ -9,7 +9,7 @@ get_models <- function(fixed, random = NULL, data, auxvars = NULL,
   if (missing(data))
     errormsg("No dataset given.")
 
-  if (!is.null(auxvars) & class(auxvars) != 'formula')
+  if (!is.null(auxvars) & !inherits(auxvars, "formula"))
     errormsg("The argument %s should be a formula.", dQuote("auxvars"))
 
   models_user <- models
@@ -67,13 +67,28 @@ get_models <- function(fixed, random = NULL, data, auxvars = NULL,
   group_lvls <- colSums(!identify_level_relations(groups))
   max_lvl <- max(group_lvls)
 
+
+  dat_all <- if (any(!allvars %in% names(data))) {
+    cbind(data[, allvars[allvars %in% names(data)], drop = FALSE],
+          sapply(allvars[!allvars %in% names(data)], function(x) {
+            eval(parse(text = x), envir = data)
+          }, simplify = FALSE)
+    )
+  } else {
+    data[, allvars, drop = FALSE]
+  }
+
+    all_lvls <- get_datlvls(dat_all, groups)
+
+
+
+
   if (length(allvars) > 0) {
 
     varinfo <- sapply(allvars, function(k) {
       x <- eval(parse(text = k), envir = data)
       out <- k %in% names(fixed)
-      lvl <- group_lvls[
-        check_varlevel(x, groups, group_lvls = identify_level_relations(groups))]
+      lvl <- group_lvls[all_lvls[k]]
       nmis <- sum(is.na(x[match(unique(groups[[names(lvl)]]),
                                 groups[[names(lvl)]])]))
       nlev <- length(levels(x))
