@@ -1,7 +1,10 @@
 
 library("JointAI")
 
-Sys.setenv(IS_CHECK = "true")
+skip_on_cran()
+
+cat("ON CRAN:", testthat:::on_cran(), "\n")
+
 if (identical(Sys.getenv("NOT_CRAN"), "true")) {
   set_seed(1234)
   wideDF <- JointAI::wideDF
@@ -299,30 +302,28 @@ if (identical(Sys.getenv("NOT_CRAN"), "true")) {
   })
 
   test_that("data_list remains the same", {
-    skip_on_cran()
-    print_output(lapply(models, "[[", "data_list"), type = "value",
-                 context = "glm")
+    expect_snapshot(lapply(models, "[[", "data_list"))
   })
 
   test_that("jagsmodel remains the same", {
     skip_on_cran()
-    print_output(lapply(models, "[[", "jagsmodel"), context = "glm")
+    expect_snapshot(lapply(models, "[[", "jagsmodel"))
   })
 
   test_that("GRcrit and MCerror give same result", {
     skip_on_cran()
-    print_output(lapply(models0, GR_crit, multivariate = FALSE), context = "glm")
-    print_output(lapply(models0, MC_error), context = "glm")
+    expect_snapshot(lapply(models0, GR_crit, multivariate = FALSE))
+    expect_snapshot(lapply(models0, MC_error))
   })
 
 
   test_that("summary output remained the same", {
     skip_on_cran()
-    print_output(lapply(models0, print), context = "glm")
-    print_output(lapply(models0, coef), context = "glm")
-    print_output(lapply(models0, confint), context = "glm")
-    print_output(lapply(models0, summary, missinfo = TRUE), context = "glm")
-    print_output(lapply(models0, function(x) coef(summary(x))), context = "glm")
+    expect_snapshot(lapply(models0, print))
+    expect_snapshot(lapply(models0, coef))
+    expect_snapshot(lapply(models0, confint))
+    expect_snapshot(lapply(models0, summary, missinfo = TRUE))
+    expect_snapshot(lapply(models0, function(x) coef(summary(x))))
   })
 
 
@@ -405,4 +406,4 @@ if (identical(Sys.getenv("NOT_CRAN"), "true")) {
                         warn = FALSE, mess = FALSE))
   })
 }
-Sys.setenv(IS_CHECK = "")
+# Sys.setenv(IS_CHECK = "")
